@@ -119,8 +119,9 @@ class Automation:
         print ('Path to CM repositories:    {}'.format(self.cmind.repos_path))
 
         print ('')
-        print ('GitHub for CM development:  https://github.com/mlcommons/ck/tree/master/cm')
-        print ('Reporting issues and ideas: https://github.com/mlcommons/ck/issues')
+        print ('GitHub for CM developments:        https://github.com/mlcommons/ck/tree/master/cm')
+        print ('GitHub for CM automation scripts:  https://github.com/mlcommons/ck/tree/master/cm-mlops')
+        print ('Reporting issues and ideas:        https://github.com/mlcommons/ck/issues')
 
         return {'return':0}
 
@@ -1026,9 +1027,12 @@ class Automation:
             automation_alias = meta.get('automation_alias','')
             automation_uid = meta.get('automation_uid','')
 
+            x = utils.assemble_cm_object(alias,uid)
+            if ' ' in x: x = '"' + x + '"'
+            
             cid = utils.assemble_cm_object(automation_alias,automation_uid) + \
                   '::' + \
-                  utils.assemble_cm_object(alias,uid)
+                  x
             
 #            cid_user_friendly = automation_alias if automation_alias != '' else automation_uid
 #            cid_user_friendly += '::' + (alias if alias != '' else uid)
@@ -1037,8 +1041,18 @@ class Automation:
 #            cid = automation_uid + '::' + uid
 
             # Output if console
+            full_cid = '(' + cid + ')'
             if console:
-                print (cid)
-                print ('  '+path)
+                print ('CID = ' + cid)
+                print ('CID2 = ' + full_cid)
+                print ('Path = ' + path)
+
+            # Attempt to copy to clipboard (if pacakge is installed)
+            try:
+                import pyperclip
+                pyperclip.copy(' = ' + full_cid)
+            except:
+                pass
+
 
         return {'return':0, 'list': lst}
