@@ -1,4 +1,4 @@
-﻿# Auxilary functions for CM
+# Auxilary functions for CM
 
 # Some functionality was reused from the CK framework for compatibility
 
@@ -34,7 +34,7 @@ def load_yaml_and_json(file_name_without_ext, check_if_exists = False, encoding
     meta = {}
 
     not_found = True
-    
+
     for file_ext in [('.yaml', load_yaml), 
                      ('.json', load_json)]:
         file_name = file_name_without_ext + file_ext[0]
@@ -168,7 +168,10 @@ def load_json(file_name, check_if_exists = False, encoding='utf8'):
     import json
 
     with open(file_name, encoding=encoding) as jf:
-        meta = json.load(jf)
+        try:
+            meta = json.load(jf)
+        except Exception as e:
+            return {'return':4, 'error': format(e)}
 
     return {'return':0,
             'meta': meta}
@@ -232,11 +235,14 @@ def load_yaml(file_name, check_if_exists = False, encoding = 'utf8'):
     import yaml
 
     with open(file_name, 'rt', encoding = encoding) as yf:
-        if int(yaml.__version__[0])>=5:
-            meta = yaml.load(yf, Loader=yaml.FullLoader)
-        else:
-            # To support old versions
-            meta = yaml.safe_load(yf)
+        try:
+            if int(yaml.__version__[0])>=5:
+                meta = yaml.load(yf, Loader=yaml.FullLoader)
+            else:
+                # To support old versions
+                meta = yaml.safe_load(yf)
+        except Exception as e:
+            return {'return':4, 'error': format(e)}
 
     return {'return':0,
             'meta': meta}
@@ -271,7 +277,7 @@ def load_txt(file_name, encoding = 'utf8', remove_after_read = False,
 
     if check_if_exists and not os.path.isfile(file_name):
         return {'return':16, 'error':'{} was not found'.format(file_name)}
-    
+
     with open(file_name, 'rt', encoding = encoding) as tf:
         s = tf.read()
 
@@ -289,8 +295,8 @@ def load_txt(file_name, encoding = 'utf8', remove_after_read = False,
         match = re.search(match_text, s)
 
         if fail_if_no_match!='' and match is None:
-            return {'return':1, 'error': fail_if_no_match}
-        
+            return {'return':1, 'error': fail_if_no_match, 'string':s}
+
         rr['match'] = match
 
     return rr
